/****
* Classes
****/
// Define a class for obstacles
var Obstacle = Container.expand(function () {
var self = Container.call(this);
var obstacleGraphics = self.attachAsset('obstacle', {
anchorX: 0.5,
anchorY: 0.5
});
self.speed = 5;
self.update = function () {
self.y += self.speed;
if (self.y > 2732) {
self.destroy();
}
};
});
var Obstacle2 = Container.expand(function () {
var self = Container.call(this);
var obstacleGraphics = self.attachAsset('obstacle2', {
anchorX: 0.5,
anchorY: 0.5
});
self.speed = 5;
self.update = function () {
self.y += self.speed;
if (self.y > 2732) {
self.destroy();
}
};
});
// Assets will be automatically created and loaded by the LK engine based on their usage in the code.
// Define a class for the player's car
var PlayerCar = Container.expand(function () {
var self = Container.call(this);
var carGraphics = self.attachAsset('playerCar', {
anchorX: 0.5,
anchorY: 0.5
});
self.speed = 10;
self.update = function () {
// Update logic for the player's car
};
});
/****
* Initialize Game
****/
var game = new LK.Game({
backgroundColor: 0x000000 // Init game with black background
});
/****
* Game Code
****/
// Initialize game variables
var playerCar;
var obstacles = [];
var score = 0;
var scoreTxt;
var difficulty = 'Medium'; // Default difficulty
// Add event listeners for difficulty buttons
LK.gui.topLeft.addChild(new Text2('Easy', {
size: 50,
fill: "#ffffff"
}).on('down', function () {
difficulty = 'Easy';
}));
LK.gui.top.addChild(new Text2('Medium', {
size: 50,
fill: "#ffffff"
}).on('down', function () {
difficulty = 'Medium';
}));
LK.gui.topRight.addChild(new Text2('Hard', {
size: 50,
fill: "#ffffff"
}).on('down', function () {
difficulty = 'Hard';
}));
// Function to handle game updates
game.update = function () {
// Update player car
playerCar.update();
// Update obstacles
for (var i = obstacles.length - 1; i >= 0; i--) {
// Adjust speed increment based on score and difficulty
var baseSpeed = 5;
if (difficulty === 'Easy') {
baseSpeed = 3;
} else if (difficulty === 'Hard') {
baseSpeed = 7;
}
obstacles[i].speed = baseSpeed + Math.floor(score / 20);
obstacles[i].update();
if (playerCar.intersects(obstacles[i])) {
LK.effects.flashScreen(0xff0000, 1000);
LK.showGameOver();
} else {
score += 1; // Increase score
scoreTxt.setText('Score: ' + score); // Update score display
}
}
// Spawn new obstacles
// Adjust spawn frequency based on difficulty
var spawnInterval = Math.max(20, 50 - Math.floor(score / 15));
if (difficulty === 'Easy') {
spawnInterval += 10;
} else if (difficulty === 'Hard') {
spawnInterval -= 10;
}
if (LK.ticks % spawnInterval == 0) {
// Decrease interval based on score
var newObstacle;
if (Math.random() > 0.5) {
newObstacle = new Obstacle();
} else {
newObstacle = new Obstacle2();
}
newObstacle.x = Math.random() * 2048;
newObstacle.y = -50;
obstacles.push(newObstacle);
game.addChild(newObstacle);
}
};
// Function to handle player car movement
game.move = function (x, y, obj) {
playerCar.x = x;
playerCar.y = y;
};
// Initialize player car
playerCar = new PlayerCar();
playerCar.x = 2048 / 2;
playerCar.y = 2732 - 200;
game.addChild(playerCar);
// Initialize score text
scoreTxt = new Text2('Score: 0', {
size: 100,
fill: "#ffffff"
});
scoreTxt.anchor.set(0.5, 0);
LK.gui.top.addChild(scoreTxt); ===================================================================
--- original.js
+++ change.js
@@ -58,15 +58,42 @@
var playerCar;
var obstacles = [];
var score = 0;
var scoreTxt;
+var difficulty = 'Medium'; // Default difficulty
+// Add event listeners for difficulty buttons
+LK.gui.topLeft.addChild(new Text2('Easy', {
+ size: 50,
+ fill: "#ffffff"
+}).on('down', function () {
+ difficulty = 'Easy';
+}));
+LK.gui.top.addChild(new Text2('Medium', {
+ size: 50,
+ fill: "#ffffff"
+}).on('down', function () {
+ difficulty = 'Medium';
+}));
+LK.gui.topRight.addChild(new Text2('Hard', {
+ size: 50,
+ fill: "#ffffff"
+}).on('down', function () {
+ difficulty = 'Hard';
+}));
// Function to handle game updates
game.update = function () {
// Update player car
playerCar.update();
// Update obstacles
for (var i = obstacles.length - 1; i >= 0; i--) {
- obstacles[i].speed = 5 + Math.floor(score / 20); // Adjust speed increment based on score
+ // Adjust speed increment based on score and difficulty
+ var baseSpeed = 5;
+ if (difficulty === 'Easy') {
+ baseSpeed = 3;
+ } else if (difficulty === 'Hard') {
+ baseSpeed = 7;
+ }
+ obstacles[i].speed = baseSpeed + Math.floor(score / 20);
obstacles[i].update();
if (playerCar.intersects(obstacles[i])) {
LK.effects.flashScreen(0xff0000, 1000);
LK.showGameOver();
@@ -75,9 +102,16 @@
scoreTxt.setText('Score: ' + score); // Update score display
}
}
// Spawn new obstacles
- if (LK.ticks % Math.max(20, 50 - Math.floor(score / 15)) == 0) {
+ // Adjust spawn frequency based on difficulty
+ var spawnInterval = Math.max(20, 50 - Math.floor(score / 15));
+ if (difficulty === 'Easy') {
+ spawnInterval += 10;
+ } else if (difficulty === 'Hard') {
+ spawnInterval -= 10;
+ }
+ if (LK.ticks % spawnInterval == 0) {
// Decrease interval based on score
var newObstacle;
if (Math.random() > 0.5) {
newObstacle = new Obstacle();